@@ -31,6 +31,7 @@
 #include "vinagre-prefs.h"
 #include "view/autoDrawer.h"
 #include "vinagre-plugins-engine.h"
+#include "vinagre-vala.h"
 
 #define VINAGRE_TAB_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), VINAGRE_TYPE_TAB, VinagreTabPrivate))
 
@@ -634,7 +635,7 @@ void
 vinagre_tab_add_view (VinagreTab *tab, GtkWidget *view)
 {
   GtkWidget *viewport;
-  GdkColor color = {0,};
+  GdkRGBA color = {0,};
 
   g_return_if_fail (VINAGRE_IS_TAB (tab));
 
@@ -643,7 +644,7 @@ vinagre_tab_add_view (VinagreTab *tab, GtkWidget *view)
 					 view);
   viewport = gtk_bin_get_child (GTK_BIN (tab->priv->scroll));
   gtk_viewport_set_shadow_type(GTK_VIEWPORT (viewport), GTK_SHADOW_NONE);
-  gtk_widget_modify_bg (viewport, GTK_STATE_NORMAL, &color);
+  gtk_widget_override_background_color (viewport, GTK_STATE_NORMAL, &color);
 }
 
 /**
@@ -880,9 +881,10 @@ vinagre_tab_take_screenshot (VinagreTab *tab)
   GdkPixbuf     *pix;
   GtkWidget     *dialog;
   GString       *suggested_filename;
-  gchar         *name;
+  gchar         *name, *timestamp;
   GtkFileFilter *filter, *initial_filter;
   GSList        *formats, *l;
+  GDateTime     *localtime;
 
   g_return_if_fail (VINAGRE_IS_TAB (tab));
 
@@ -909,13 +911,18 @@ vinagre_tab_take_screenshot (VinagreTab *tab)
 
   name = vinagre_connection_get_best_name (tab->priv->conn);
   suggested_filename = g_string_new (NULL);
-  /* Translators: This is the suggested filename (in save dialog) when taking a screenshot of the connection. %s will be replaced by the friendly name of the connection, for instance: Screenshot of wendell@wendell-laptop, or Screenshot of 200.100.100.123 */
-  g_string_printf (suggested_filename, _("Screenshot of %s"), name);
+  /* Translators: This is the suggested filename (in save dialog) when taking a screenshot of the connection. First %s will be replaced by the friendly name of the connection and the second %s by the current date and time, for instance: Screenshot of wendell@wendell-laptop at 2011-10-29 12:34:11, or Screenshot of 200.100.100.123 at 2011-10-29 18:27:11 */
+  localtime = g_date_time_new_now_local ();
+  timestamp =  g_date_time_format (localtime, "%F %H:%M:%S");
+  g_string_printf (suggested_filename, _("Screenshot of %s at %s"), name, timestamp);
   g_string_append (suggested_filename, ".png");
   g_free (name);
+  g_free (timestamp);
+  g_date_time_unref (localtime);
   gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), suggested_filename->str);
   g_string_free (suggested_filename, TRUE);
 
+  /* FIXME: Assumes that the PNG format is always supported by GdkPixbuf. */
   formats = get_supported_image_formats ();
   for (l = formats; l; l = l->next)
     {
